@@ -129,11 +129,12 @@ class CsrfProtect(object):
     def init_app(self, app):
         app.jinja_env.globals['csrf_token'] = generate_csrf
         strict = app.config.get('WTF_CSRF_SSL_STRICT', True)
+        csrf_enabled = app.config.get('WTF_CSRF_ENABLED', True)
 
         @app.before_request
         def _csrf_protect():
             # many things come from django.middleware.csrf
-            if app.testing:
+            if not csrf_enabled:
                 return
 
             if request.method in ('GET', 'HEAD', 'OPTIONS', 'TRACE'):
@@ -152,13 +153,15 @@ class CsrfProtect(object):
                     return
 
             csrf_token = None
-            if request.method == 'POST':
-                # DELETE has no form
+            if request.method in ('POST', 'PUT', 'PATCH'):
                 csrf_token = request.form.get('csrf_token')
             if not csrf_token:
                 # You can get csrf token from header
                 # The header name is the same as Django
                 csrf_token = request.headers.get('X-CSRFToken')
+            if not csrf_token:
+                # The header name is the same as Rails
+                csrf_token = request.headers.get('X-CSRF-Token')
             if not validate_csrf(csrf_token):
                 reason = 'CSRF token missing or incorrect.'
                 return self._error_response(reason)
